DROP TABLE archivdaten;
DROP TABLE stuetzstellen;
DROP TABLE ganglinien;
DROP TABLE ereignisse;
DROP TABLE ereignistypen;


-- Tabelle mit den Ereignistypen 
CREATE TABLE ereignistypen (
	ereignistyp VARCHAR(50) NOT NULL,
	prioritaet INTEGER NOT NULL,
	ausschluss VARCHAR(50),
	bezug VARCHAR(50),
	typ INTEGER DEFAULT 0 NOT NULL,	
	vergleichsschrittweite BIGINT DEFAULT 60000 NOT NULL,
	max_abstand INTEGER DEFAULT 100 NOT NULL,
	max_matchingfehler INTEGER DEFAULT 15 NOT NULL,
	matchingschrittweite BIGINT DEFAULT 60000 NOT NULL,	
	matchingintervall_vor BIGINT DEFAULT 21600000 NOT NULL,
	matchingintervall_nach BIGINT DEFAULT 21600000 NOT NULL,
	max_wichtungsfaktor INTEGER DEFAULT 3 NOT NULL,
	darstellungsverfahren INTEGER DEFAULT 1 NOT NULL,
	max_ganglinien INTEGER DEFAULT 10 NOT NULL,

	PRIMARY KEY (ereignistyp),
	FOREIGN KEY (ereignistyp) REFERENCES ereignistypen(ereignistyp),
	FOREIGN KEY (ausschluss) REFERENCES ereignistypen(ereignistyp)
);
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestOstermontag', 1100);
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestMontag', 1010);
INSERT INTO ereignistypen (ereignistyp, prioritaet, ausschluss) VALUES ('TestMontagsfeiertag', 1080, 'TestMontag');
INSERT INTO ereignistypen (ereignistyp, prioritaet) VALUES ('TestDienstag', 1010);
INSERT INTO ereignistypen (ereignistyp, prioritaet, typ, bezug) VALUES ('TestSportereignis', 1220, 2, 'TestDienstag');
INSERT INTO ereignistypen (ereignistyp, prioritaet, typ, bezug) VALUES ('TestUnfall', 1200, 2, 'TestDienstag');

-- Tabelle mit den Ereignissen
-- "tag" ist der Tag an dem das Ereignis gltig sein soll, relativ zum heutigen
-- Tag: -1 = gestern, 0 = heute, 1 = morgen usw.
CREATE TABLE ereignisse (
	ereignistyp VARCHAR(50) NOT NULL,
	tag INTEGER NOT NULL,
	startzeit INTEGER DEFAULT 0 NOT NULL,
	endzeit INTEGER DEFAULT 24 NOT NULL,

	FOREIGN KEY (ereignistyp) REFERENCES ereignistypen(ereignistyp)
);
-- Erster Testtag
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestOstermontag', -9);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontagsfeiertag', -9);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontag', -9);
-- Zweiter Testtag
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontagsfeiertag', -8);
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontag', -8);
-- Dritter Testtag
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestMontag', -7);
-- Vierter Testtag
INSERT INTO ereignisse (ereignistyp, tag) VALUES ('TestDienstag', -6);
INSERT INTO ereignisse (ereignistyp, tag, startzeit, endzeit) VALUES ('TestSportereignis', -6, 8, 16);
INSERT INTO ereignisse (ereignistyp, tag, startzeit, endzeit) VALUES ('TestUnfall', -6, 12, 20);


-- Tabelle mit den Ganglinie
CREATE TABLE ganglinien (
	id INTEGER NOT NULL,
	ereignistyp VARCHAR(50) NOT NULL,
	typ INTEGER DEFAULT 0 NOT NULL,
	approximation INTEGER DEFAULT 1 NOT NULL,
	referenz BOOLEAN DEFAULT false NOT NULL,

	PRIMARY KEY (id),
	FOREIGN KEY (ereignistyp) REFERENCES ereignistypen(ereignistyp)
);
INSERT INTO ganglinien (id, ereignistyp) VALUES (0, 'TestOstermontag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (1, 'TestOstermontag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (2, 'TestOstermontag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (3, 'TestMontagsfeiertag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (4, 'TestMontagsfeiertag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (5, 'TestMontagsfeiertag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (6, 'TestMontag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (7, 'TestMontag');
INSERT INTO ganglinien (id, ereignistyp) VALUES (8, 'TestMontag');
INSERT INTO ganglinien (id, ereignistyp, approximation) VALUES (9, 'TestDienstag', 2);
INSERT INTO ganglinien (id, ereignistyp, approximation) VALUES (10, 'TestDienstag', 2);
INSERT INTO ganglinien (id, ereignistyp, approximation) VALUES (11, 'TestDienstag', 2);
INSERT INTO ganglinien (id, ereignistyp, typ, approximation) VALUES (12, 'TestSportereignis', 2, 2);
INSERT INTO ganglinien (id, ereignistyp, typ, approximation) VALUES (13, 'TestSportereignis', 2, 2);
INSERT INTO ganglinien (id, ereignistyp, typ, approximation) VALUES (14, 'TestSportereignis', 2, 2);
INSERT INTO ganglinien (id, ereignistyp, typ, approximation) VALUES (15, 'TestUnfall', 2, 2);
INSERT INTO ganglinien (id, ereignistyp, typ, approximation) VALUES (16, 'TestUnfall', 2, 2);
INSERT INTO ganglinien (id, ereignistyp, typ, approximation) VALUES (17, 'TestUnfall', 2, 2);


-- Tabelle mit den Sttzstellen der Ganglinien
-- "tag" ist der Tag an dem das Ereignis gltig sein soll, relativ zum heutigen
-- Tag: -1 = gestern, 0 = heute, 1 = morgen usw.
-- undefinierte Stzstellenwerte sind NULL
CREATE TABLE stuetzstellen (
	gl_id INTEGER NOT NULL,
	tag INTEGER NOT NULL,
	stunde INTEGER NOT NULL,
	qkfz REAL,
	qlkw REAL,
	vpkw REAL,
	vlkw REAL,
	
	PRIMARY KEY (gl_id, tag, stunde),
	FOREIGN KEY (gl_id) REFERENCES ganglinien(id)
);


-- Testdaten fr Ganglinien importieren
CREATE TEXT TABLE csvimport_ganglinien (
	ganglinie INTEGER NOT NULL,
	tag INTEGER NOT NULL,
	stunde INTEGER NOT NULL,
	qkfz REAL,
	qlkw REAL,
	vpkw REAL,
	vlkw REAL
);
SET TABLE csvimport_ganglinien SOURCE "prueffall8_ganglinien.csv;ignore_first=true;fs=\semi";
INSERT INTO stuetzstellen (gl_id, tag, stunde, qkfz, qlkw, vpkw, vlkw)
	SELECT ganglinie, tag, stunde, qkfz, qlkw, vpkw, vlkw FROM csvimport_ganglinien;
SET TABLE csvimport_ganglinien SOURCE OFF;
DROP TABLE csvimport_ganglinien;


-- Tabelle mit den Archivdaten
-- "tag" ist der Tag an dem das Ereignis gltig sein soll, relativ zum heutigen
-- Tag: -1 = gestern, 0 = heute, 1 = morgen usw.
CREATE TABLE archivdaten (
	tag INTEGER NOT NULL,
	stunde INTEGER NOT NULL,
	qkfz REAL,
	qlkw REAL,
	vpkw REAL,
	vlkw REAL
);


-- Testdaten fr Archiv importieren
CREATE TEXT TABLE csvimport_archiv(
	tag INTEGER NOT NULL,
	stunde INTEGER NOT NULL,
	qkfz REAL,
	qlkw REAL,
	vpkw REAL,
	vlkw REAL
);
SET TABLE csvimport_archiv SOURCE "prueffall8_archivdaten.csv;ignore_first=true;fs=\semi";
INSERT INTO archivdaten (tag, stunde, qkfz, qlkw, vpkw, vlkw)
	SELECT tag, stunde, qkfz, qlkw, vpkw, vlkw FROM csvimport_archiv;
SET TABLE csvimport_archiv SOURCE OFF;
DROP TABLE csvimport_archiv;
